==> ssp-center-api-0.2.54-20180621.055053-2-sources.jar: cn/com/duiba/tuia/ssp/center/api/dto/SendNoticeMsgDto.java <==
package cn.com.duiba.tuia.ssp.center.api.dto;

import io.swagger.annotations.ApiModelProperty;

import java.io.Serializable;
import java.util.Date;

/**
 * 发送通知信息
 */
public class SendNoticeMsgDto implements Serializable {

    private static final long serialVersionUID = -3485284912641925261L;

    /*通知主题ID*/
    private Long id;

    /**
     * 通知主题
     */
    private String title;

    /**
     * news类型（0：推啊头条，1：推啊玩法，2：推啊季刊）
     */
    private Integer newsType;

    /**
     * 封面url
     */
    private String coverUrl;

    /**
     * 简介
     */
    private String introduction;
    
    /**
     * 用户id
     */
    private Long mediaId;
    /**
     * 内容
     */
    private String content;
    /**
     * 状态
     */
    private Integer status;
    /**
     * 发送者
     */
    private String sender;
    /**
     * 发送时间
     */
    private Date sendTime;


    public String getContent() {
        return content;
    }

    public void setContent(String content) {
        this.content = content;
    }

    public Integer getStatus() {
        return status;
    }

    public void setStatus(Integer status) {
        this.status = status;
    }

    public String getSender() {
        return sender;
    }

    public void setSender(String sender) {
        this.sender = sender;
    }

    public Date getSendTime() {
        return sendTime;
    }

    public void setSendTime(Date sendTime) {
        this.sendTime = sendTime;
    }

    public Long getMediaId() {
        return mediaId;
    }

    public void setMediaId(Long mediaId) {
        this.mediaId = mediaId;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public Integer getNewsType() {
        return newsType;
    }

    public void setNewsType(Integer newsType) {
        this.newsType = newsType;
    }

    public String getCoverUrl() {
        return coverUrl;
    }

    public void setCoverUrl(String coverUrl) {
        this.coverUrl = coverUrl;
    }

    public String getIntroduction() {
        return introduction;
    }

    public void setIntroduction(String introduction) {
        this.introduction = introduction;
    }
}

==> ssp-center-api-0.2.68-20180820.035735-51-sources.jar: cn/com/duiba/tuia/ssp/center/api/dto/SendNoticeMsgDto.java <==
package cn.com.duiba.tuia.ssp.center.api.dto;

import io.swagger.annotations.ApiModelProperty;

import java.io.Serializable;
import java.util.Date;

/**
 * 发送通知信息
 */
public class SendNoticeMsgDto implements Serializable {

    private static final long serialVersionUID = -3485284912641925261L;

    /*通知主题ID*/
    private Long id;

    /**
     * 通知主题
     */
    private String title;

    /**
     * news类型（0：推啊头条，1：推啊玩法，2：推啊季刊）
     */
    private Integer newsType;

    /**
     * 封面url
     */
    private String coverUrl;

    /**
     * 简介
     */
    private String introduction;
    
    /**
     * 用户id
     */
    private Long mediaId;
    /**
     * 内容
     */
    private String content;
    /**
     * 状态
     */
    private Integer status;
    /**
     * 发送者
     */
    private String sender;
    /**
     * 发送时间
     */
    private Date sendTime;

    /**
     * 外链
     */
    private String outerChainUrl;


    public String getContent() {
        return content;
    }

    public void setContent(String content) {
        this.content = content;
    }

    public Integer getStatus() {
        return status;
    }

    public void setStatus(Integer status) {
        this.status = status;
    }

    public String getSender() {
        return sender;
    }

    public void setSender(String sender) {
        this.sender = sender;
    }

    public Date getSendTime() {
        return sendTime;
    }

    public void setSendTime(Date sendTime) {
        this.sendTime = sendTime;
    }

    public Long getMediaId() {
        return mediaId;
    }

    public void setMediaId(Long mediaId) {
        this.mediaId = mediaId;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public Integer getNewsType() {
        return newsType;
    }

    public void setNewsType(Integer newsType) {
        this.newsType = newsType;
    }

    public String getCoverUrl() {
        return coverUrl;
    }

    public void setCoverUrl(String coverUrl) {
        this.coverUrl = coverUrl;
    }

    public String getIntroduction() {
        return introduction;
    }

    public void setIntroduction(String introduction) {
        this.introduction = introduction;
    }

    public String getOuterChainUrl() {
        return outerChainUrl;
    }

    public void setOuterChainUrl(String outerChainUrl) {
        this.outerChainUrl = outerChainUrl;
    }
}
